@@ -158,71 +158,71 @@ class BzrClientTest(BzrClientTestSetups):
         self.assertEqual(client.get_version(), new_version)
         
 
-# class BzrDiffStatClientTest(BzrClientTestSetups):
+class BzrDiffStatClientTest(BzrClientTestSetups):
 
-#     @classmethod
-#     def setUpClass(self):
-#         # setup a local repo once for all diff and status test
-#         BzrClientTestSetups.setUpClass()
-#         url = self.remote_path
-#         client = BzrClient(self.local_path)
-#         client.checkout(url)
-#         # after setting up "local" repo, change files and make some changes
-#         subprocess.check_call(["rm", "deleted-fs.txt"], cwd=self.local_path)
-#         subprocess.check_call(["bzr", "rm", "deleted.txt"], cwd=self.local_path)
-#         f = io.open(os.path.join(self.local_path, "modified.txt"), 'a')
-#         f.write(u'0123456789abcdef')
-#         f.close()
-#         f = io.open(os.path.join(self.local_path, "modified-fs.txt"), 'a')
-#         f.write(u'0123456789abcdef')
-#         f.close()
-#         f = io.open(os.path.join(self.local_path, "added-fs.txt"), 'w')
-#         f.write(u'0123456789abcdef')
-#         f.close()
-#         f = io.open(os.path.join(self.local_path, "added.txt"), 'w')
-#         f.write(u'0123456789abcdef')
-#         f.close()
-#         subprocess.check_call(["bzr", "add", "added.txt"], cwd=self.local_path)
+    @classmethod
+    def setUpClass(self):
+        # setup a local repo once for all diff and status test
+        BzrClientTestSetups.setUpClass()
+        url = self.remote_path
+        client = BzrClient(self.local_path)
+        client.checkout(url)
+        # after setting up "local" repo, change files and make some changes
+        subprocess.check_call(["rm", "deleted-fs.txt"], cwd=self.local_path)
+        subprocess.check_call(["bzr", "rm", "deleted.txt"], cwd=self.local_path)
+        f = io.open(os.path.join(self.local_path, "modified.txt"), 'a')
+        f.write(u'0123456789abcdef')
+        f.close()
+        f = io.open(os.path.join(self.local_path, "modified-fs.txt"), 'a')
+        f.write(u'0123456789abcdef')
+        f.close()
+        f = io.open(os.path.join(self.local_path, "added-fs.txt"), 'w')
+        f.write(u'0123456789abcdef')
+        f.close()
+        f = io.open(os.path.join(self.local_path, "added.txt"), 'w')
+        f.write(u'0123456789abcdef')
+        f.close()
+        subprocess.check_call(["bzr", "add", "added.txt"], cwd=self.local_path)
 
-#     def tearDown(self):
-#         pass
+    def tearDown(self):
+        pass
 
-#     @classmethod
-#     def tearDownClass(self):
-#         BzrClientTestSetups.tearDownClass()
+    @classmethod
+    def tearDownClass(self):
+        BzrClientTestSetups.tearDownClass()
         
-#     def test_diff(self):
-#         client = BzrClient(self.local_path)
-#         self.assertTrue(client.path_exists())
-#         self.assertTrue(client.detect_presence())
-#         # using fnmatch because date and time change (remove when bzr reaches diff --format)
-#         diff=client.get_diff()
-#         self.assertTrue(diff is not None)
-#         self.assertTrue(fnmatch.fnmatch(diff,"=== added file 'added.txt'\n--- ./added.txt\t????-??-?? ??:??:?? +0000\n+++ ./added.txt\t????-??-?? ??:??:?? +0000\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\n\n=== removed file 'deleted-fs.txt'\n=== removed file 'deleted.txt'\n=== modified file 'modified-fs.txt'\n--- ./modified-fs.txt\t????-??-?? ??:??:?? +0000\n+++ ./modified-fs.txt\t????-??-?? ??:??:?? +0000\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\n\n=== modified file 'modified.txt'\n--- ./modified.txt\t????-??-?? ??:??:?? +0000\n+++ ./modified.txt\t????-??-?? ??:??:?? +0000\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\n\n"))
+    def test_diff(self):
+        client = BzrClient(self.local_path)
+        self.assertTrue(client.path_exists())
+        self.assertTrue(client.detect_presence())
+        # using fnmatch because date and time change (remove when bzr reaches diff --format)
+        diff=client.get_diff()
+        self.assertTrue(diff is not None)
+        self.assertTrue(fnmatch.fnmatch(diff,"=== added file 'added.txt'\n--- ./added.txt\t????-??-?? ??:??:?? +0000\n+++ ./added.txt\t????-??-?? ??:??:?? +0000\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\n\n=== removed file 'deleted-fs.txt'\n=== removed file 'deleted.txt'\n=== modified file 'modified-fs.txt'\n--- ./modified-fs.txt\t????-??-?? ??:??:?? +0000\n+++ ./modified-fs.txt\t????-??-?? ??:??:?? +0000\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\n\n=== modified file 'modified.txt'\n--- ./modified.txt\t????-??-?? ??:??:?? +0000\n+++ ./modified.txt\t????-??-?? ??:??:?? +0000\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\n\n"))
 
-#     def test_diff_relpath(self):
-#         client = BzrClient(self.local_path)
-#         self.assertTrue(client.path_exists())
-#         self.assertTrue(client.detect_presence())
-#         # using fnmatch because date and time change (remove when bzr introduces diff --format)
-#         diff = client.get_diff(basepath=os.path.dirname(self.local_path))
-#         self.assertTrue(diff is not None)
-#         self.assertTrue(fnmatch.fnmatch(diff, "=== added file 'added.txt'\n--- local/added.txt\t????-??-?? ??:??:?? +0000\n+++ local/added.txt\t????-??-?? ??:??:?? +0000\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\n\n=== removed file 'deleted-fs.txt'\n=== removed file 'deleted.txt'\n=== modified file 'modified-fs.txt'\n--- local/modified-fs.txt\t????-??-?? ??:??:?? +0000\n+++ local/modified-fs.txt\t????-??-?? ??:??:?? +0000\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\n\n=== modified file 'modified.txt'\n--- local/modified.txt\t????-??-?? ??:??:?? +0000\n+++ local/modified.txt\t????-??-?? ??:??:?? +0000\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\n\n"))
+    def test_diff_relpath(self):
+        client = BzrClient(self.local_path)
+        self.assertTrue(client.path_exists())
+        self.assertTrue(client.detect_presence())
+        # using fnmatch because date and time change (remove when bzr introduces diff --format)
+        diff = client.get_diff(basepath=os.path.dirname(self.local_path))
+        self.assertTrue(diff is not None)
+        self.assertTrue(fnmatch.fnmatch(diff, "=== added file 'added.txt'\n--- local/added.txt\t????-??-?? ??:??:?? +0000\n+++ local/added.txt\t????-??-?? ??:??:?? +0000\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\n\n=== removed file 'deleted-fs.txt'\n=== removed file 'deleted.txt'\n=== modified file 'modified-fs.txt'\n--- local/modified-fs.txt\t????-??-?? ??:??:?? +0000\n+++ local/modified-fs.txt\t????-??-?? ??:??:?? +0000\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\n\n=== modified file 'modified.txt'\n--- local/modified.txt\t????-??-?? ??:??:?? +0000\n+++ local/modified.txt\t????-??-?? ??:??:?? +0000\n@@ -0,0 +1,1 @@\n+0123456789abcdef\n\\ No newline at end of file\n\n"))
 
-#     def test_status(self):
-#         client = BzrClient(self.local_path)
-#         self.assertTrue(client.path_exists())
-#         self.assertTrue(client.detect_presence())
-#         self.assertEquals('+N  ./added.txt\n D  ./deleted-fs.txt\n-D  ./deleted.txt\n M  ./modified-fs.txt\n M  ./modified.txt\n', client.get_status())
+    def test_status(self):
+        client = BzrClient(self.local_path)
+        self.assertTrue(client.path_exists())
+        self.assertTrue(client.detect_presence())
+        self.assertEquals('+N  ./added.txt\n D  ./deleted-fs.txt\n-D  ./deleted.txt\n M  ./modified-fs.txt\n M  ./modified.txt\n', client.get_status())
 
-#     def test_status_relpath(self):
-#         client = BzrClient(self.local_path)
-#         self.assertTrue(client.path_exists())
-#         self.assertTrue(client.detect_presence())
-#         self.assertEquals('+N  local/added.txt\n D  local/deleted-fs.txt\n-D  local/deleted.txt\n M  local/modified-fs.txt\n M  local/modified.txt\n', client.get_status(basepath=os.path.dirname(self.local_path)))
+    def test_status_relpath(self):
+        client = BzrClient(self.local_path)
+        self.assertTrue(client.path_exists())
+        self.assertTrue(client.detect_presence())
+        self.assertEquals('+N  local/added.txt\n D  local/deleted-fs.txt\n-D  local/deleted.txt\n M  local/modified-fs.txt\n M  local/modified.txt\n', client.get_status(basepath=os.path.dirname(self.local_path)))
 
-#     def test_status_untracked(self):
-#         client = BzrClient(self.local_path)
-#         self.assertTrue(client.path_exists())
-#         self.assertTrue(client.detect_presence())
-#         self.assertEquals('?   ./added-fs.txt\n+N  ./added.txt\n D  ./deleted-fs.txt\n-D  ./deleted.txt\n M  ./modified-fs.txt\n M  ./modified.txt\n', client.get_status(untracked=True))
+    def test_status_untracked(self):
+        client = BzrClient(self.local_path)
+        self.assertTrue(client.path_exists())
+        self.assertTrue(client.detect_presence())
+        self.assertEquals('?   ./added-fs.txt\n+N  ./added.txt\n D  ./deleted-fs.txt\n-D  ./deleted.txt\n M  ./modified-fs.txt\n M  ./modified.txt\n', client.get_status(untracked=True))
